@@ -4,9 +4,9 @@
  * GChemPaint library
  * atom.h 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -29,7 +29,8 @@
 
 #include <map>
 #include <glib.h>
-#include <chemistry/atom.h>
+#include <gcu/atom.h>
+#include <gcu/element.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include "widgetdata.h"
 
@@ -55,6 +56,17 @@ class gcpMolecule;
 #define CHARGE_E 64
 #define CHARGE_W 128
 
+#define POSITION_NE 1
+#define POSITION_NW 2
+#define POSITION_N 4
+#define POSITION_SE 8
+#define POSITION_SW 16
+#define POSITION_S 32
+#define POSITION_E 64
+#define POSITION_W 128
+
+class gcpElectron;
+
 class gcpAtom: public Atom
 {
 public:
@@ -74,23 +86,40 @@ public :
 	int GetAttachedHydrogens() {return m_nH;}
 	bool GetBestSide();
 	bool IsInCycle(gcpCycle* pCycle);
-	virtual int GetChargePosition(double& x, double& y);
+	virtual int GetChargePosition(unsigned char& Pos, double Angle, double& x, double& y);
+	virtual int GetAvailablePosition(double& x, double& y);
+	virtual bool GetPosition(double angle, double& x, double& y);
+	virtual xmlNodePtr Save (xmlDocPtr xml);
+	virtual bool Load (xmlNodePtr);
 	virtual bool LoadNode(xmlNodePtr);
 	virtual void SetSelected(GtkWidget* w, int state);
 	virtual bool AcceptNewBonds(int nb = 1);
+	virtual bool AcceptCharge (int charge);
+	virtual double GetYAlign ();
 	/*!
 	@param Mol: a pointer to a molecule
-	
+
 	Adds the atom to the molecule calling gcpMolecule::AddAtom()
 	*/
 	virtual void AddToMolecule(gcpMolecule* Mol);
+	bool HasImplicitElectronPairs ();
+	bool MayHaveImplicitUnpairedElectrons ();
+	void AddElectron (gcpElectron* electron);
+	void NotifyPositionOccupation (unsigned char pos, bool occupied);
+	void SetChargePosition (unsigned char Pos, bool def, double angle = 0., double distance = 0.);
+	char GetChargePosition (double *Angle, double *Dist);
 
 private:
-	void AddChargeItem(gcpWidgetData* pData, GnomeCanvasGroup* group);
+	void BuildItems (gcpWidgetData* pData);
+	void UpdateAvailablePositions ();
 
 private:
+	Element *m_Element;
 	int m_nH;
-	int m_Valence, m_nve; //valence, number of valence electrons
+	int m_Valence; //valence
+	int m_ValenceOrbitals;
+	int m_nlp; //lone electron pairs number
+	int m_nlu; //single electrons number
 	double m_width, m_height; //size of the atomic symbol in the canvas
 	double m_length, m_text_height; // size of the text buffer
 	bool m_HPos; //false = left, true = right
@@ -100,6 +129,16 @@ private:
 	int m_ascent;
 	int m_lbearing;
 	double m_CHeight;
+	unsigned char m_AvailPos; //available standard positions for charge and electrons representations
+	unsigned char m_OccupiedPos;
+	bool m_AvailPosCached;
+	unsigned char m_ChargePos;
+	bool m_ChargeAutoPos;
+	double m_ChargeAngle;
+	double m_ChargeDist;
+	list<double> m_AngleList;
+	map<double, double> m_InterBonds; /* positions betwen bonds. First  value is the
+	angle between the two bonds and second value is the direction */
 };
 
 #endif // GCHEMPAINT_ATOM_H
