@@ -4,9 +4,9 @@
  * GChemPaint library
  * fragment-atom.h 
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -45,7 +45,7 @@ public:
 	virtual void SetSelected(GtkWidget* w, int state);
 	virtual xmlNodePtr Save(xmlDocPtr xml);
 	virtual bool Load(xmlNodePtr node);
-	virtual int GetChargePosition(char& Pos, double Angle, double& x, double& y);
+	virtual int GetChargePosition(unsigned char& Pos, double Angle, double& x, double& y);
 	virtual int GetAvailablePosition(double& x, double& y);
 	virtual bool GetPosition(double angle, double& x, double& y);
 	virtual bool AcceptCharge (int charge);
