@@ -4,7 +4,7 @@
  * GChemPaint library
  * fragment.cc 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -106,6 +106,7 @@ bool gcpFragment::OnChanged(GtkTextBuffer *textbuffer)
 		m_height = rect.height + 1;
 		m_length = 1;
 		pView->Update (this);
+		EmitSignal (OnChangedSignal);
 		m_bLoading = false;
 		return true;
 	}
@@ -341,16 +342,17 @@ void gcpFragment::Add(GtkWidget* w)
 						"grow_height", false,
 						"editable", false,
 						"cursor_visible", false,
+						"text_direction", GTK_TEXT_DIR_LTR,
 						NULL);
 	g_object_set_data(G_OBJECT(group), "fragment", item);
 	gnome_canvas_rich_text_ext_set_buffer(GNOME_CANVAS_RICH_TEXT_EXT(item), m_buf);
 	g_object_set_data(G_OBJECT(item), "object", this);
 	g_signal_connect(G_OBJECT(item), "event", G_CALLBACK(on_event), w);
 	/* add charge */
-	int charge = !m_Atom->GetCharge ();
+	int charge = m_Atom->GetCharge ();
 	if (charge) {
 		double x, y, Angle, Dist;
-		char Pos = m_Atom->gcpAtom::GetChargePosition (&Angle, &Dist);
+		unsigned char Pos = m_Atom->gcpAtom::GetChargePosition (&Angle, &Dist);
 		int align = GetChargePosition(m_Atom, Pos, 0., x, y);
 		if (Dist != 0.) {
 			x = m_x + Dist * cos (Angle);
@@ -443,7 +445,7 @@ void gcpFragment::Update(GtkWidget* w)
 	int charge = m_Atom->GetCharge ();
 	if (charge) {
 		double x, y, Angle, Dist;
-		char Pos = m_Atom->gcpAtom::GetChargePosition (&Angle, &Dist);
+		unsigned char Pos = m_Atom->gcpAtom::GetChargePosition (&Angle, &Dist);
 		if (item) {
 			int align = GetChargePosition(m_Atom, Pos, Angle, x, y);
 			if (Dist != 0.) {
@@ -603,6 +605,7 @@ bool gcpFragment::SavePortion(xmlDocPtr xml, xmlNodePtr node, GtkTextIter& start
 												GTK_DIALOG_DESTROY_WITH_PARENT,
 												GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 												"Invalid charge.");
+				gtk_window_set_icon_name (GTK_WINDOW (w), "gchempaint");
 				gtk_dialog_run(GTK_DIALOG(w));
 				gtk_widget_destroy(w);
 				return false;
@@ -1009,7 +1012,7 @@ int gcpFragment::GetElementAtIter(GtkTextIter* start, GtkTextIter* end)
 	return 0;
 }
 
-int gcpFragment::GetChargePosition(gcpFragmentAtom* pAtom, char& Pos, double Angle, double& x, double& y)
+int gcpFragment::GetChargePosition(gcpFragmentAtom* pAtom, unsigned char& Pos, double Angle, double& x, double& y)
 {
 	if ((pAtom != m_Atom) || (m_Atom->GetZ() == 0)) return 0;
 	GtkTextIter iter;
@@ -1053,7 +1056,7 @@ int gcpFragment::GetChargePosition(gcpFragmentAtom* pAtom, char& Pos, double Ang
 		if ((result & CHARGE_E) && ((angle <= 225.0) && (angle >= 135.0))) result -= CHARGE_E;
 		if ((result & CHARGE_W) && (angle >= 315.0) || (angle <= 45.0)) result -= CHARGE_W;
 	}
-	if (Pos == -1) {
+	if (Pos == 0xff) {
 		if (result) {
 			if (result & CHARGE_NE)
 				Pos = CHARGE_NE;
@@ -1131,6 +1134,7 @@ bool gcpFragment::Validate()
 										GTK_DIALOG_DESTROY_WITH_PARENT,
 										GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 										_("Invalid symbol."));
+		gtk_window_set_icon_name (GTK_WINDOW (w), "gchempaint");
 		gtk_dialog_run(GTK_DIALOG(w));
 		gtk_widget_destroy(w);
 		gtk_text_buffer_get_iter_at_mark(m_buf, &start, m_BeginAtom);
@@ -1160,6 +1164,7 @@ bool gcpFragment::Validate()
 											GTK_DIALOG_DESTROY_WITH_PARENT,
 											GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE,
 											_("Invalid charge."));
+			gtk_window_set_icon_name (GTK_WINDOW (w), "gchempaint");
 			gtk_dialog_run(GTK_DIALOG(w));
 			gtk_widget_destroy(w);
 			gtk_text_buffer_move_mark_by_name(m_buf, "selection_bound", &start);
