@@ -4,9 +4,9 @@
  * GChemPaint libray
  * settings.h 
  *
--2002 * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -44,7 +44,7 @@ extern double DefaultArrowHeadB;
 extern double DefaultArrowHeadC;
 extern double DefaultArrowDist;
 extern double DefaultArrowPadding;
-extern double DefaultStoechiometryPadding;
+extern double DefaultStoichiometryPadding;
 extern double DefaultObjectPadding;
 extern double DefaultSignPadding;
 extern gchar *Color, *DeleteColor, *AddColor, *SelectColor;
