@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -39,6 +39,8 @@
 #include <pango/pango-context.h>
 #include <gdk/gdkkeysyms.h>
 #include <libgnomeprint/gnome-print-job.h>
+#include <locale.h>
+#include <fstream>
 
 /*
 Derivation of a new widget from gnome_canvas with an event for updating canvas size
@@ -814,7 +816,7 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	ArtDRect rect;
 	m_pData->GetObjectBounds (m_pDoc, &rect);
 	m_pData->ShowSelection (false);
-	int w = (int) (ceil (rect.x1) - floor (rect.x0)) + 1, h = (int) (ceil (rect.y1) - floor (rect.y0)) + 1;
+	int w = (int) (floor (rect.x1) - ceil (rect.x0)) + 1, h = (int) (floor (rect.y1) - ceil (rect.y0));
 	if (!strcmp (type, "eps")) {
 		GnomePrintConfig* config = gnome_print_config_default();
 		GnomePrintContext *pc;
@@ -830,19 +832,165 @@ void gcpView::ExportImage (const char* filename, const char* type)
 		char *tmpname = g_strdup ("/tmp/gcp2epsXXXXXX");
 		int f = g_mkstemp (tmpname);
 		close (f);
+		double hp, mt, ml;
+		GnomePrintUnit const *unit;
+		GnomePrintUnit const *inches = gnome_print_unit_get_by_abbreviation ((const guchar *) "in");
+		gnome_print_config_get_length (config, (const guchar*) "Settings.Output.Media.PhysicalSize.Height", &hp, &unit);
+		gnome_print_convert_distance (&hp, unit, inches);
+		hp *= 72;
+/*		gnome_print_config_get_length (config, (const guchar*) "Settings.Document.Page.Margins.Left", &ml, &unit);
+		gnome_print_convert_distance (&ml, unit, inches);
+		ml *= 72;
+		gnome_print_config_get_length (config, (const guchar*) "Settings.Document.Page.Margins.Top", &mt, &unit);
+		gnome_print_convert_distance (&mt, unit, inches);
+		mt *= 72;	*/
+		ml = mt = 30.; // see gcpView::Print !
 		gnome_print_config_set_boolean (config, (const guchar*) "Settings.Output.Job.PrintToFile", true);
 		gnome_print_config_set (config, (const guchar*) GNOME_PRINT_KEY_OUTPUT_FILENAME, (const guchar*) tmpname);
 		gnome_print_job_print (gpj);
 		g_object_unref (gpj);
 		gnome_print_config_unref(config);
-		char *command_line = g_strconcat ("ps2eps ", tmpname, NULL);
-		g_spawn_command_line_sync (command_line, NULL, NULL, NULL, NULL);
-		g_free (command_line);
-		command_line = g_strconcat ("mv -f ", tmpname, ".eps ", filename, NULL);
-		g_spawn_command_line_async (command_line, NULL);
-		remove (tmpname);
-		g_free (tmpname);
-		g_free (command_line);
+		char buf[256];
+		ifstream *fin = new ifstream (tmpname);
+		ofstream *fout = new ofstream (filename);
+		*fout << "%!PS-Adobe-3.0 EPSF-3.0" << endl;
+		*fout << "%%BoundingBox: " << (int) (rect.x0 * .75 + ml) << " " << (int) (hp - mt - rect.y1 * .75)  <<  " "  << (int) (rect.x1 * .75 + ml) << " " << (int) (hp - mt - rect.y0 * .75) << endl;
+		*fout << "%%HiResBoundingBox: " << rect.x0 * .75 + ml << " " << hp - mt - rect.y1 * .75 <<  " "  << rect.x1 * .75 + ml << " " << hp - mt - rect.y0 * .75 << endl;
+		fin->getline (buf, 256);
+		while (!fin->eof ()) {
+			fin->getline (buf, 256);
+			if (strlen (buf) >= 255)
+				exit (-1); /* This is violent but should not occur */
+			if (!strncmp (buf, "%%", 2)) {
+				if (!strncmp (buf + 2, "Orientation", strlen ("Orientation")))
+					continue;
+				else if (!strncmp (buf + 2, "Pages", strlen ("Pages")))
+					continue;
+				else if (!strncmp (buf + 2, "BoundingBox", strlen ("BoundingBox")))
+					continue;
+				else if (!strncmp (buf + 2, "BeginDefaults", strlen ("BeginDefaults")))
+					continue;
+				else if (!strncmp (buf + 2, "EndDefaults", strlen ("EndDefaults")))
+					continue;
+				else if (!strncmp (buf + 2, "BeginSetup", strlen ("BeginSetup")))
+					continue;
+				else if (!strncmp (buf + 2, "EndSetup", strlen ("EndSetup")))
+					continue;
+				else if (!strncmp (buf + 2, "PageMedia", strlen ("PageMedia")))
+					continue;
+				else if (!strncmp (buf + 2, "EndProlog", strlen ("EndProlog")))
+					continue;
+				else if (!strncmp (buf + 2, "BeginResource", strlen ("BeginResource")))
+					continue;
+				else if (!strncmp (buf + 2, "EndResource", strlen ("EndResource")))
+					continue;
+				else if (!strncmp (buf + 2, "Page: ", strlen ("Page: ")))
+					continue;
+				else if (!strncmp (buf + 2, "%%", 2))
+					continue;
+				else if (!strncmp (buf + 2, "PageResources", strlen ("PageResources")))
+					continue;
+				else if (!strncmp (buf + 2, "EndComments", strlen ("EndComments"))) {
+					 *fout << buf << endl;
+					if (!strcmp (filename + strlen (filename) - 5, ".epsi")) {
+						gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
+						GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
+						GnomeCanvasBuf cbuf;
+						int i, j, mask, lines, bytes;
+						unsigned char b;
+						cbuf.buf = gdk_pixbuf_get_pixels (pixbuf);
+						cbuf.rect.x0 = (int) floor (rect.x0);
+						cbuf.rect.x1 = (int) ceil (rect.x1);
+						cbuf.rect.y0 = (int) floor (rect.y0);
+						cbuf.rect.y1 = (int) ceil (rect.y1);
+						cbuf.buf_rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+						cbuf.bg_color = 0xffffff;
+						cbuf.is_buf = 1;
+						(* GNOME_CANVAS_ITEM_GET_CLASS (m_pData->Group)->render) (GNOME_CANVAS_ITEM (m_pData->Group), &cbuf);
+						/* use 8 bits depth, no more than 250 bytes per line*/
+						lines = (w + 249) / 250 * h;
+						*fout << "%%BeginPreview: " << w << " " << h << " " << 8 << " " << lines << endl;
+						*fout << hex;
+						for (j = 0; j < h; j++) {
+							bytes = 0;
+							for (i = 0; i < 3 * w; i+= 3) {
+								if (bytes == 0)
+									*fout << "%";
+								mask = 0xff - (cbuf.buf[i] + cbuf.buf[i + 1] + cbuf.buf[i + 2]) / 3;
+								*fout << (mask & 0xf);
+								mask = mask >> 4;
+								*fout << mask;
+								bytes++;
+								if (bytes == 250) {
+									*fout << endl;
+									bytes = 0;
+								}
+							}
+							if (bytes)
+								*fout << endl;
+							cbuf.buf += cbuf.buf_rowstride;
+						}
+						/* use 1 bit depth, no more than 128 bytes per line (max width 1024) */
+/*						lines = (w + 1023) / 1024 * h;
+						*fout << "%%BeginPreview: " << w << " " << h << " " << 1 << " " << lines << endl;
+						*fout << hex;
+						for (j = 0; j < h; j++) {
+							mask = 1; b = 0;
+							bytes = 0;
+							for (i = 0; i < 3 * w; i+= 3) {
+								if (bytes == 0)
+									*fout << "%";
+								if ((cbuf.buf[i] + cbuf.buf[i + 1] + cbuf.buf[i + 2]) / 3 < 0x80)
+									b |= mask;
+								mask <<= 1;
+								if (mask == 16) {
+									*fout << (int) b;
+									mask = 1;
+									b = 0;
+									bytes++;
+									if (bytes == 128) {
+										*fout << endl;
+										bytes = 0;
+									}
+								}
+							}
+							if (mask != 1) {
+								*fout << (int) b;
+								bytes++;
+							}
+							if (bytes)
+								*fout << endl;
+							cbuf.buf += cbuf.buf_rowstride;
+						}*/
+						*fout << dec;
+						*fout << "%%EndPreview" << endl;
+						g_object_unref (pixbuf);
+					}
+				} else if (!strncmp (buf + 2, "BeginProlog", strlen ("BeginProlog"))) {
+					 *fout << buf << endl;
+					 *fout << "save" << endl;
+					 *fout << "countdictstack" << endl;
+					 *fout << "mark" << endl;
+					 *fout << "newpath" << endl;
+					 *fout << "/showpage {} def" << endl;
+					 *fout << "/setpagedevice {pop} def" << endl;
+					 *fout << "%%EndProlog" << endl;
+					 *fout << "%%Page 1 1" << endl;
+				} else if (!strncmp (buf + 2, "Trailer", strlen ("Trailer"))) {
+					 *fout << buf << endl;
+					 *fout << "cleartomark" << endl;
+					 *fout << "countdictstack" << endl;
+					 *fout << "exch sub { end } repeat" << endl;
+					 *fout << "restore" << endl;
+				} else 
+					 *fout << buf << endl;
+			} else
+			 *fout << buf << endl;
+		}
+		fin->close ();
+		delete fin;
+		fout->close ();
+		delete fout;
 	} else if (!strcmp (type, "svg")) {
 		xmlDocPtr doc = xmlNewDoc ((const xmlChar*)"1.0");
 		char *old_num_locale = g_strdup (setlocale (LC_NUMERIC, NULL));
