@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2003-2005
  *
- * Developed by Jean Bréfort <jean.brefort@n>ormalesup.org
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -77,7 +77,7 @@ bool gcpChargeTool::OnClicked()
 		if (item)
 			gnome_canvas_item_hide (item);
 		double x, y;
-		m_DefaultPos = -1;
+		m_DefaultPos = 0xff;
 		int align = ((gcpAtom*)m_pObject)->GetChargePosition(m_DefaultPos, 0., x, y);
 		if (!align) return false;
 		m_Pos = m_DefaultPos;
