@@ -4,9 +4,9 @@
  * GChemPaint atoms plugin
  * chargetool.h 
  *
- * Copyright (C) 2002-2004
+ * Copyright (C) 2002-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -41,6 +41,9 @@ public:
 
 private:
 	char* m_glyph;
+	double m_dDist, m_dDistMax, m_dAngle;
+	int m_Charge;
+	unsigned char m_Pos, m_DefaultPos;
 };
 
 #endif	//GCHEMPAINT_CHARGE_TOOL_H
