@@ -18,7 +18,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -49,6 +49,7 @@ gcpGroupDlg::gcpGroupDlg (gcpDocument *Doc, gcpGroup *group):
 	group_btn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "group_btn"));
 	space_btn = GTK_TOGGLE_BUTTON (glade_xml_get_widget (xml, "space"));
 	padding_btn = GTK_SPIN_BUTTON (glade_xml_get_widget (xml, "padding"));
+	dist_lbl = glade_xml_get_widget (xml, "dist_lbl");
 	if (group) {
 		gtk_toggle_button_set_active (group_btn, true);
 		gcpAlignType type;
@@ -152,8 +153,24 @@ bool gcpGroupDlg::Apply ()
 
 void gcpGroupDlg::OnAlignToggled ()
 {
+	if (gtk_toggle_button_get_active (align_btn)) {
+		gtk_widget_set_sensitive (GTK_WIDGET (align_box), true);
+		gtk_widget_set_sensitive (GTK_WIDGET (space_btn), true);
+		gtk_widget_set_sensitive (GTK_WIDGET (padding_btn), true);
+	} else {
+		gtk_widget_set_sensitive (GTK_WIDGET (align_box), false);
+		gtk_toggle_button_set_active (space_btn, false);
+		gtk_widget_set_sensitive (GTK_WIDGET (space_btn), false);
+	}
 }
 
 void gcpGroupDlg::OnSpaceToggled ()
 {
+	if (gtk_toggle_button_get_active (space_btn)) {
+		gtk_widget_set_sensitive (GTK_WIDGET (padding_btn), true);
+		gtk_widget_set_sensitive (dist_lbl, true);
+	} else {
+		gtk_widget_set_sensitive (GTK_WIDGET (padding_btn), false);
+		gtk_widget_set_sensitive (dist_lbl, false);
+	}
 }
